@@ -10,19 +10,24 @@
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #
-# import os
-# import sys
-# sys.path.insert(0, os.path.abspath('.'))
+import os
+import sys
+
+HERE = os.path.abspath(os.path.dirname(__file__) or '.')
+ROOT = os.path.abspath(os.path.join(HERE, '..', '..'))
+
+sys.path.insert(0, HERE)
+sys.path.insert(0, os.path.join(ROOT, 'lib'))
 
 
 # -- Project information -----------------------------------------------------
 
 project = 'urlwatch'
-copyright = '2022 Thomas Perl'
+copyright = '2023 Thomas Perl'
 author = 'Thomas Perl'
 
 # The full version, including alpha/beta/rc tags
-release = '2.25'
+release = '2.26'
 
 
 # -- General configuration ---------------------------------------------------
@@ -31,6 +36,7 @@ release = '2.25'
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
+    'inheritance_ascii_tree',
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -52,7 +58,7 @@ html_theme = 'alabaster'
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
+html_static_path = []
 
 master_doc = 'index'
 
